@@ -17,7 +17,7 @@ Yahoo::Marketing::AccountService - an object that provides access to Yahoo Marke
 
 See EWS documentation online for available SOAP methods:
 
-http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/services/AccountService.asp
+L<http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/services/AccountService.asp>
 
 Also see perldoc Yahoo::Marketing::Service for functionality common to all service modules.
 
